pub async fn MountainWorkspaceListFolders(
state: State<'_, Arc<ApplicationState>>,
) -> Result<Vec<WorkspaceFolderPayload>, String>Expand description
Return the current workspace folder set without mutating anything.
pub async fn MountainWorkspaceListFolders(
state: State<'_, Arc<ApplicationState>>,
) -> Result<Vec<WorkspaceFolderPayload>, String>Return the current workspace folder set without mutating anything.